@@ -29,7 +29,8 @@ class Enough(object):
         self.args.update(kwargs)
 
         self.dotenough = DotEnough(self.config_dir, self.args['domain'])
-        self.ansible = ansible_utils.Ansible(self.config_dir, self.share_dir)
+        self.ansible = ansible_utils.Ansible(self.config_dir, self.share_dir,
+                                             self.args.get('inventory'))
         if self.args.get('driver') == 'openstack':
             if 'cloud' not in self.args:
                 self.args['cloud'] = self.ansible.get_global_variable('openstack_cloud')
@@ -39,7 +40,8 @@ class Enough(object):
         if self.args.get('driver') == 'openstack':
             self.openstack = OpenStack(self.config_dir, **self.args)
             self.heat = Heat(self.config_dir, **self.args)
-        self.playbook = ansible_utils.Playbook(self.config_dir, self.share_dir)
+        self.playbook = ansible_utils.Playbook(self.config_dir, self.share_dir,
+                                               self.args.get('inventory'))
 
     def create_missings(self, hosts):
         public_key = f'{self.config_dir}/infrastructure_key.pub'
@@ -68,8 +70,7 @@ class Enough(object):
         sh.sudo.tar('-xf', self._vpn_credentials_path(),
                     _cwd='/etc/openvpn/client')
 
-        network_prefix = self.ansible.get_variable('openvpn',
-                                                   'openstack_internal_network_prefix',
+        network_prefix = self.ansible.get_variable('openstack_internal_network_prefix',
                                                    'bind-host')
         sh.sudo.openvpn(
             '--config', 'localhost.conf',
@@ -91,7 +92,7 @@ class Enough(object):
 
     @staticmethod
     def replace_production(clouds, target_cloud):
-        content = yaml.load(open(clouds))
+        content = yaml.safe_load(open(clouds))
         content['clouds']['production'] = content['clouds'][target_cloud]
         del content['clouds'][target_cloud]
         open(clouds, 'w').write(yaml.dump(content))
@@ -112,7 +113,7 @@ class Enough(object):
             all_dir = f'{config_dir}/inventory/group_vars/all'
             open(f'{all_dir}/internal_network.yml', 'w').write(textwrap.dedent(f"""\
             ---
-            openstack_internal_network_prefix: "10.11.10.0"
+            openstack_internal_network_prefix: "10.11.10"
             openstack_internal_network_cidr: "10.11.10.0/24"
             """))
             clone_override_dir = f'{config_base}/clone-override'
@@ -125,6 +126,7 @@ class Enough(object):
         kwargs = {
             'driver': self.args['driver'],
             'domain': target_domain,
+            'provider': self.args['provider'],
         }
         clone = Enough(config_dir, self.share_dir, **kwargs)
         return clone
