@@ -16,7 +16,7 @@ class Hosts(object):
 
     def load(self):
         if os.path.exists(self.f):
-            self.hosts = yaml.load(open(self.f).read())['all']['hosts']
+            self.hosts = yaml.safe_load(open(self.f).read())['all']['hosts']
         else:
             self.hosts = {}
         return self
@@ -96,7 +96,7 @@ class DotEnough(object):
         if not os.path.exists(f'{d}/private-key.yml'):
             open(f'{d}/private-key.yml', 'w').write(textwrap.dedent(f"""\
             ---
-            ssh_private_keyfile: {self.config_dir}/infrastructure_key
+            ansible_ssh_private_key_file: {self.config_dir}/infrastructure_key
             """))
 
         if not os.path.exists(f'{d}/domain.yml'):
@@ -116,7 +116,7 @@ class DotEnough(object):
     def service_add_to_group(self, service, host):
         s = f'{self.config_dir}/inventory/services.yml'
         if os.path.exists(s):
-            services = yaml.load(open(s).read())
+            services = yaml.safe_load(open(s).read())
         else:
             services = {}
         group = self.service2group(service)
@@ -137,9 +137,10 @@ class DotEnough(object):
 
 class DotEnoughOpenStack(DotEnough):
 
-    def __init__(self, config_dir, domain):
+    def __init__(self, config_dir, domain, provider):
         super().__init__(config_dir, domain)
         self.clouds_file = f'{self.config_dir}/inventory/group_vars/all/clouds.yml'
+        self.provider = provider
 
     def set_clouds_file(self, clouds_file):
         shutil.copy(clouds_file, self.clouds_file)
@@ -149,6 +150,13 @@ class DotEnoughOpenStack(DotEnough):
         self.populate_config('letsencrypt')
         self.set_missing_config_file_from_openrc(f'{self.config_dir}/openrc.sh', self.clouds_file)
 
+        d = f'{self.config_dir}/inventory/group_vars/all'
+        if not os.path.exists(f'{d}/openstack-provider.yml'):
+            open(f'{d}/openstack-provider.yml', 'w').write(textwrap.dedent(f"""\
+            ---
+            openstack_provider: {self.provider}
+            """))
+
     @staticmethod
     def set_missing_config_file_from_openrc(openrc, config_file):
         if os.path.exists(openrc) and not os.path.exists(config_file):
