@@ -1,3 +1,4 @@
+import ast
 import base64
 import datetime
 import json
@@ -12,6 +13,7 @@ import time
 import yaml
 
 from enough import settings
+from enough.common import ansible_utils
 from enough.common.retry import retry
 from enough.common.dotenough import Hosts
 
@@ -30,14 +32,16 @@ class OpenStackBase(object):
         self.o = sh.openstack.bake(
             '--os-cloud', kwargs.get('cloud', 'production'),
             _tee=True,
+            _tty_out=False,
             _out=lambda x: log.info(x.strip()),
             _err=lambda x: log.info(x.strip()),
             _env={'OS_CLIENT_CONFIG_FILE': self.config_file},
         )
 
     @staticmethod
-    @retry((socket.timeout, ConnectionRefusedError), 9)
+    @retry((socket.timeout, ConnectionRefusedError, OSError), 9)
     def wait_for_ssh(ip, port):
+        log.info('Check if SSH is available on %s:%s', ip, port)
         s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         s.settimeout(5)
         s.connect((ip, int(port)))
@@ -68,12 +72,14 @@ class Stack(OpenStackBase):
         ]
         if 'flavor' in d:
             parameters.append(f'--parameter=flavor={d["flavor"]}')
+        if 'image' in d:
+            parameters.append(f'--parameter=image={d["image"]}')
         if 'port' in d:
             parameters.append(f'--parameter=port={d["port"]}')
         if 'volumes' in d and int(d['volumes'][0]['size']) > 0:
             parameters.append(f"--parameter=volume_size={d['volumes'][0]['size']}")
             parameters.append(f"--parameter=volume_name={d['volumes'][0]['name']}")
-        if 'network' in d:
+        if d.get('network'):
             parameters.append(f'--parameter=network={d["network"]}')
             parameters.append(
                 f'--parameter=network_interface_unconfigured={d["network_interface_unconfigured"]}')
@@ -184,43 +190,40 @@ class Stack(OpenStackBase):
 class Heat(OpenStackBase):
 
     def get_stack_definitions(self, share_dir=settings.SHARE_DIR):
-        args = ['-i', f'{share_dir}/inventory',
-                '-i', f'{self.config_dir}/inventory']
-        if self.args.get('inventory'):
-            args.extend([f'--inventory={i}' for i in self.args['inventory']])
-        args.extend(['--vars', '--list'])
-        password_file = f'{self.config_dir}.pass'
-        if os.path.exists(password_file):
-            args.extend(['--vault-password-file', password_file])
-        r = sh.ansible_inventory(*args)
-        inventory = json.loads(r.stdout)
-        return inventory['_meta']['hostvars']
+        ansible = ansible_utils.Ansible(self.config_dir, share_dir,
+                                        self.args.get('inventory'))
+        return ansible.get_hostvars(variable=None)
 
     def get_stack_definition(self, host):
-        h = self.get_stack_definitions()[host]
-        if h.get('network_internal_only', False):
-            network_interface_unconfigured = h.get('network_primary_interface', 'eth0')
-            network_interface_routed = h.get('network_secondary_interface', 'eth1')
+        hostvars = self.get_stack_definitions()[host]
+        return Heat.hostvars_to_stack(host, hostvars)
+
+    @staticmethod
+    def hostvars_to_stack(host, hv):
+        if hv.get('network_internal_only'):
+            network_interface_unconfigured = hv['network_primary_interface']
+            network_interface_routed = hv['network_secondary_interface']
             network_interface_not_routed = 'noname'
         else:
             network_interface_unconfigured = 'noname'
-            network_interface_routed = h.get('network_primary_interface', 'eth0')
-            network_interface_not_routed = h.get('network_secondary_interface', 'eth1')
+            network_interface_routed = hv['network_primary_interface']
+            network_interface_not_routed = hv['network_secondary_interface']
         definition = {
             'name': host,
-            'port': h.get('ansible_port', '22'),
-            'flavor': h.get('openstack_flavor', 's1-2'),
-            'network': h.get('openstack_network', 'Ext-Net'),
-            'network_internal_only': h.get('network_internal_only', False),
+            'port': hv.get('ansible_port', '22'),
+            'flavor': hv['openstack_flavor'],
+            'image': hv['openstack_image'],
+            'network': hv.get('openstack_network'),
+            'network_internal_only': hv.get('network_internal_only'),
             'network_interface_unconfigured': network_interface_unconfigured,
             'network_interface_routed': network_interface_routed,
             'network_interface_not_routed': network_interface_not_routed,
             'internal_network': OpenStackBase.INTERNAL_NETWORK,
-            'internal_network_cidr': h.get('openstack_internal_network_cidr',
-                                           OpenStackBase.INTERNAL_NETWORK_CIDR),
+            'internal_network_cidr': hv.get('openstack_internal_network_cidr',
+                                            OpenStackBase.INTERNAL_NETWORK_CIDR),
         }
-        if 'openstack_volumes' in h:
-            definition['volumes'] = h['openstack_volumes']
+        if 'openstack_volumes' in hv:
+            definition['volumes'] = hv['openstack_volumes']
         return definition
 
     def host_from_volume(self, name):
@@ -330,7 +333,7 @@ class OpenStack(OpenStackBase):
 
     def __init__(self, config_dir, **kwargs):
         super().__init__(config_dir, **kwargs)
-        self.config = yaml.load(open(self.config_file))
+        self.config = yaml.safe_load(open(self.config_file))
 
     @retry(OpenStackLeftovers, tries=7)
     def destroy_everything(self, prefix):
@@ -338,11 +341,12 @@ class OpenStack(OpenStackBase):
         leftovers = []
 
         def delete_snapshots():
-            for snapshot in self.o.volume.snapshot.list('--format=value', '-c', 'Name', _iter=True):
-                snapshot = snapshot.strip()
-                if prefix is None or prefix in snapshot:
-                    leftovers.append(f'snapshot({snapshot})')
-                    self.o.volume.snapshot.delete(snapshot)
+            snapshots = self.o.volume.snapshot.list('--format=json',
+                                                    '-c', 'Name', '-c', 'ID')
+            for snapshot in json.loads(snapshots.stdout):
+                if prefix is None or prefix in snapshot['Name']:
+                    leftovers.append(f'snapshot({snapshot["ID"]})')
+                    self.o.volume.snapshot.delete(snapshot['ID'])
 
         def delete_stacks():
             r = self.o.stack.list('--format=json', '-c', 'Stack Name', '-c', 'Stack Status')
@@ -361,17 +365,18 @@ class OpenStack(OpenStackBase):
                     self.o.image.delete(image)
 
         def delete_volumes():
-            for volume in self.o.volume.list('--format=value', '-c', 'Name', _iter=True):
-                volume = volume.strip()
-                if prefix is None or prefix in volume:
-                    leftovers.append(f'volume({volume})')
-                    self.o.volume.delete(volume)
+            volumes = self.o.volume.list('--format=json', '-c', 'Name',
+                                         '-c', 'ID')
+
+            for volume in json.loads(volumes.stdout):
+                if prefix is None or prefix in volume['Name']:
+                    leftovers.append(f'volume({volume["ID"]})')
+                    self.o.volume.delete(volume['ID'])
 
         def delete_networks():
-            for network in self.o.network.list('--format=value', '-c', 'Name', _iter=True):
+            for network in self.o.network.list('--no-share', '--format=value', '-c', 'Name',
+                                               _iter=True):
                 network = network.strip()
-                if network == 'Ext-Net':
-                    continue
                 if prefix is None or prefix in network:
                     leftovers.append(f'network({network})')
                     self.o.network.delete(network)
@@ -416,9 +421,12 @@ class OpenStack(OpenStackBase):
     def network_delete_if_not_used(self, name):
         if not self.network_exists(name):
             return
-        ports = self.o.port.list('--device-owner=compute:None',
-                                 '--network', name, '--format=value', '-c', 'ID')
-        if ports.strip() == '':
+
+        ports = self.o.port.list('--network', name, '--format=json', '-c',
+                                 'ID', '-c', 'device_owner')
+        ports = [port for port in json.loads(str(ports))
+                 if port['device_owner'].startswith('compute:')]
+        if not ports:
             self.o.network.delete(name)
 
     def subnet_exists(self, name):
@@ -444,16 +452,20 @@ class OpenStack(OpenStackBase):
     def server_connected_to_network(self, server, network):
         return self.server_ip_in_network(server, network)
 
-    def server_ip_in_network(self, server, network):
-        info = self.o.port.list('--server', server, '--network', network,
+    def server_port_list(self, server, network):
+        return self.o.port.list('--server', server, '--network', network,
                                 '--format=value', '-c', 'Fixed IP Addresses')
-        info = info.strip()
+
+    def server_ip_in_network(self, server, network):
+        info = self.server_port_list(server, network).strip()
         if info == '':
             return None
-        pattern = r"ip_address='([0-9.]*?)'"
-        m = re.search(pattern, info)
-        assert m, f're.search({pattern}, {info})'
-        return m.group(1)
+        pattern = r"^[0-9.]+$"
+        found = None
+        for subnet in ast.literal_eval(info):
+            if re.match(pattern, subnet['ip_address']):
+                found = subnet['ip_address']
+        return found
 
     def backup_date(self):
         return datetime.datetime.today().strftime('%Y-%m-%d')
@@ -512,7 +524,7 @@ class OpenStack(OpenStackBase):
         r = self.o.volume.snapshot.list(
             '--format=json', '--long', '-c', 'Volume', '--limit', '5000')
         volumes_with_snapshots = set([x["Volume"] for x in json.loads(r.stdout)])
-        r = self.o.volume.list('--format=json', '-c', 'Name', '--limit', '5000')
+        r = self.o.volume.list('--format=json', '-c', 'Name', '-c', 'ID', '--limit', '5000')
         before = (datetime.datetime.today() - datetime.timedelta(days)).strftime('%Y-%m-%d')
         info = {
             'no_date_prefix': [],
@@ -520,9 +532,9 @@ class OpenStack(OpenStackBase):
             'deleted': [],
             'recent': [],
         }
-        for volume in set([x["Name"] for x in json.loads(r.stdout)]):
+        for volume, volume_id in set([(x["Name"], x["ID"]) for x in json.loads(r.stdout)]):
             if re.match(r'^\d\d\d\d\-\d\d-\d\d-', volume):
-                if volume in volumes_with_snapshots:
+                if volume_id in volumes_with_snapshots:
                     info['has_snapshots'].append(volume)
                 elif volume[:10] < before:
                     self.o.volume.delete(volume)
@@ -538,18 +550,20 @@ class OpenStack(OpenStackBase):
         status = self.o.server.show('--format=value', '-c=status', host)
         status = status.strip()
         if status != 'SHUTOFF':
-            raise OpenStackShutoff()
+            raise OpenStackShutoff('Unexpected status: %r' % status)
 
     def replace_volume(self, host, volume, delete_volume):
         self.o.server.stop(host)
         self.server_wait_shutoff(host)
         attached = self.o.server.show(
-            '--format=value', '-c', 'volumes_attached', host).stdout.strip()
-        current_volume_id = re.sub("id='(.*)'", "\\1", attached.decode('utf-8'))
+            '--format=yaml', '-c', 'volumes_attached', host).stdout.strip()
+        current_volume_id = yaml.safe_load(attached)['volumes_attached'][0]['id']
         current_volume = self.o.volume.show(
             '--format=value', '-c', 'name', current_volume_id).strip()
-        volume_id = self.o.volume.show('--format=value', '-c', 'id', volume).stdout.strip()
         self.o.server.remove.volume(host, current_volume_id)
+        # fetch volume id now because next block might assign an existing volume
+        # name to another volume
+        volume_id = self.o.volume.show('--format=value', '-c', 'id', volume).stdout.strip()
         if delete_volume:
             # using current_volume_id here is not possible unfortunately
             self.o.volume.delete(current_volume)
@@ -562,11 +576,12 @@ class OpenStack(OpenStackBase):
 
     def volume_resize(self, host, volume, size):
         attached = self.o.server.show(
-            '--format=value', '-c', 'volumes_attached', host).stdout.strip()
-        if len(attached) == 0:
+            '--format=yaml', '-c', 'volumes_attached', host).stdout.strip()
+        volumes_attached = yaml.safe_load(attached)['volumes_attached']
+        if not volumes_attached:
             raise OpenStackVolumeResizeMissing(
                 f'{host} is not attached {volume}, it is not attached to any volume')
-        current_volume_id = re.sub("id='(.*)'", "\\1", attached.decode('utf-8'))
+        current_volume_id = volumes_attached[0]['id']
         current_volume = self.o.volume.show(
             '--format=value', '-c', 'name', current_volume_id).strip()
         if current_volume != volume:
