@@ -7,4 +7,10 @@ def set_options(parser):
         '--cloud',
         default='production',
         help='Name of the cloud in which resources are provisionned')
+
+    o.add_argument(
+        '--provider',
+        default='ovh',
+        choices=('fuga', 'ovh'),
+        help='Name of the OpenStack provider')
     return parser
