@@ -21,14 +21,15 @@ class Create(Command):
     def take_action(self, parsed_args):
         args = vars(self.app.options)
         args.update(vars(parsed_args))
-        d = dotenough.DotEnoughOpenStack(settings.CONFIG_DIR, args['domain'])
+        d = dotenough.DotEnoughOpenStack(settings.CONFIG_DIR, args['domain'],
+                                         args['provider'])
         d.ensure()
         o = OpenStack(settings.CONFIG_DIR, **args)
         o.backup_create(args['volumes'])
 
 
 class Prune(Command):
-    "Prune old backups."
+    "Prune old backup volumes and their snapshots."
 
     log = logging.getLogger(__name__)
 
@@ -41,7 +42,9 @@ class Prune(Command):
     def take_action(self, parsed_args):
         args = vars(self.app.options)
         args.update(vars(parsed_args))
-        d = dotenough.DotEnoughOpenStack(settings.CONFIG_DIR, args['domain'])
+        d = dotenough.DotEnoughOpenStack(settings.CONFIG_DIR, args['domain'],
+                                         args['provider'])
         d.ensure()
         o = OpenStack(settings.CONFIG_DIR, **args)
         o.backup_prune(args['days'])
+        o.volume_prune(args['days'])
