@@ -17,7 +17,7 @@ testinfra_hosts = ['ansible://gitlab-host']
 
 def get_domain(inventory):
     vars_dir = f'{inventory}/group_vars/all'
-    return yaml.load(open(vars_dir + '/domain.yml'))['domain']
+    return yaml.safe_load(open(vars_dir + '/domain.yml'))['domain']
 
 
 def api_sign_in(pytestconfig, host):
