@@ -1,5 +1,6 @@
 import os
 import pytest
+import shutil
 import yaml
 
 from enough.common import Enough
@@ -35,6 +36,9 @@ def get_hosts(session, enough):
 
 
 def pytest_sessionstart(session):
+    if not session.config.getoption("--enough-no-destroy"):
+        enough_destroy(session)
+
     service_directory = session.config.getoption("--enough-service")
     provider = session.config.getoption("--provider")
     os.environ['ENOUGH_PROVIDER'] = provider
@@ -85,32 +89,26 @@ def pytest_runtest_setup(item):
 
 
 def pytest_sessionfinish(session, exitstatus):
-    if session.config.getoption("--enough-no-destroy"):
-        return
+    if not session.config.getoption("--enough-no-destroy"):
+        enough_destroy(session)
 
-    if exitstatus != 0:
-        return
 
+def enough_destroy(session):
     service_directory = session.config.getoption("--enough-service")
     provider = session.config.getoption("--provider")
     domain = f'{service_directory}.test'
     enough_dot_dir = session.config.cache.makedir('dotenough')
     config_dir = make_config_dir(domain, enough_dot_dir)
+    all_dir = f'{config_dir}/inventory/group_vars/all'
+    if not os.path.exists(all_dir):
+        os.makedirs(all_dir)
+    shutil.copyfile('inventory/group_vars/all/clouds.yml', f'{all_dir}/clouds.yml')
     e = Enough(config_dir, '.',
                domain=domain,
                driver='openstack',
                provider=provider,
                inventory=[f'playbooks/{service_directory}/inventory'])
-    (_, hosts) = get_hosts(session, e)
-    e.host.delete_hosts(hosts)
-
-    domain_file = f'{e.config_dir}/inventory/group_vars/all/domain.yml'
-    if os.path.exists(domain_file):
-        os.unlink(domain_file)
-
-    credentials = f'{config_dir}/openvpn/localhost.tar.gz'
-    if os.path.exists(credentials):
-        os.unlink(credentials)
+    e.destroy()
 
 
 def pytest_unconfigure(config):
