@@ -1,3 +1,5 @@
+from enough.common import retry
+
 testinfra_hosts = ['ansible://cloud-host']
 
 
@@ -17,12 +19,17 @@ def test_nextcloud(host):
 def test_nextcloud_via_tor(host):
     with host.sudo():
         host.run("apt-get install -y curl")
-    cmd = host.run("""
-    set -xe
-    hostname=$(sudo cat /var/lib/tor/services/cloud/hostname)
-    torsocks curl --silent http://$hostname/login |
-       grep --quiet 'This application requires JavaScript'
-    """)
-    print(cmd.stdout)
-    print(cmd.stderr)
-    assert 0 == cmd.rc
+
+    @retry.retry(AssertionError, tries=5)
+    def run():
+        cmd = host.run("""
+        set -xe
+        hostname=$(sudo cat /var/lib/tor/services/cloud/hostname)
+        torsocks curl --silent http://$hostname/login |
+           grep --quiet 'This application requires JavaScript'
+        """)
+        print(cmd.stdout)
+        print(cmd.stderr)
+        assert 0 == cmd.rc
+
+    run()
