@@ -31,8 +31,7 @@ def test_ci_runner(host, tmpdir):
     git config user.name "Your Name"
     (
      echo 'jobs:'
-     echo '  script: env > /srv/OPENSTACK.out 2>&1 ; \
-                     docker ps > /srv/DOCKER.out 2>&1'
+     echo '  script: docker ps > /srv/DOCKER.out 2>&1'
     ) > .gitlab-ci.yml
     git add .gitlab-ci.yml
     git commit -m 'test'
@@ -44,8 +43,7 @@ def test_ci_runner(host, tmpdir):
                address=f'lab.{domain}',
                directory=str(tmpdir)))
 
-    for (what, expected) in (('OPENSTACK', 'OS_PROJECT_NAME'),
-                             ('DOCKER', 'CONTAINER')):
+    for (what, expected) in (('DOCKER', 'CONTAINER'),):
         success = False
         for _ in range(40):
             if (runner_host.file('/srv/' + what + '.out').exists and
