@@ -8,7 +8,7 @@ testinfra_hosts = ['ansible://icinga-host']
 
 def get_address(inventory):
     vars_dir = f'{inventory}/group_vars/all'
-    return 'icinga.' + yaml.load(
+    return 'icinga.' + yaml.safe_load(
         open(vars_dir + '/domain.yml'))['domain']
 
 
