@@ -9,13 +9,12 @@ def test_weblate_send_mail(host):
     weblate_host = host
     postfix_host = testinfra.host.Host.get_host(
         'ansible://postfix-host',
-        ssh_identity_file=host.backend.ssh_identity_file,
         ansible_inventory=host.backend.ansible_inventory)
 
     cmd = weblate_host.run("""
     cd /srv/weblate
     sudo docker-compose -f docker-compose-infrastructure.yml exec -T weblate weblate \
-         sendtestemail loic+doomtofail@dachary.org
+         sendtestemail loic-doomtofail@dachary.org
     """)
     print(cmd.stdout)
     print(cmd.stderr)
