@@ -3,10 +3,14 @@ import os
 import pytest
 import sh
 import time
+
+from enough import settings
 from enough.common import tcp
 from enough.common.retry import retry
 from enough.common.openstack import OpenStack
 
+from tests import prepare_config_dir
+
 
 @pytest.fixture(autouse=True, scope='session')
 def debug_enough():
@@ -83,3 +87,40 @@ def openstack_name():
     yield prefix
     o = OpenStack('.')
     o.destroy_everything(prefix)
+
+
+@pytest.fixture
+def tmp_config_dir(monkeypatch, tmpdir):
+    enough_dot_dir = str(tmpdir)
+    domain = 'enough.community'
+    monkeypatch.setenv('ENOUGH_DOT', enough_dot_dir)
+    monkeypatch.setenv('ENOUGH_DOMAIN', domain)
+    config_dir = prepare_config_dir(domain, enough_dot_dir)
+    monkeypatch.setattr(settings, 'CONFIG_DIR', config_dir)
+
+
+# Some tests mock os.path.exists using the mocker fixture, use trylast in
+# order to avoid any interference
+@pytest.hookimpl(trylast=True)
+def pytest_runtest_teardown(item, nextitem):
+    assert os.path.isdir('.git')  # check cwd is the source repository
+    assert os.path.isdir('inventory/group_vars/all')  # with the expected structure
+
+    check_generated_files = [
+        'inventory/group_vars/all/openstack-provider.yml',
+        'inventory/group_vars/all/private-key.yml',
+    ]
+    if os.environ.get('GITLAB_CI'):
+        # contributors are allowed to define such files, CI isn't
+        check_generated_files.extend((
+            'infrastructure_key',
+            'infrastructure_key.pub',
+        ))
+    # first remove all these files in order to not interfere with the next
+    # tests then fail
+    found = []
+    for path in check_generated_files:
+        if os.path.exists(path):
+            found.append(path)
+            os.remove(path)
+    assert not found
