@@ -36,7 +36,8 @@ class IcingaHelper(object):
 
     def get_web_session(self):
         p = ansible_utils.Playbook('.', '.', [self.inventory])
-        username = list(p.get_role_variables('icinga2', 'icingaweb2_user').values())[0]
+        username = p.get_variable('wazuh_api_username', 'wazuh-host')
+        password = p.get_variable('wazuh_api_password', 'wazuh-host')
         password = list(p.get_role_variables('icinga2', 'icingaweb2_user_pass').values())[0]
         address = self.get_address()
         session = requests.Session()
@@ -81,7 +82,7 @@ class IcingaHelper(object):
     def get_hosts(self, host=None):
         url = self.get_api_url()
         if host:
-            url += f'/objects/hosts/f{host}?attrs=name&attrs=state'
+            url += f'/objects/hosts/{host}?attrs=name&attrs=state'
         else:
             url += f'/objects/hosts?attrs=name&attrs=state'
 
